@@ -1,8 +1,8 @@
-/* 
+/*
    +----------------------------------------------------------------------+
-   | PHP Version 5                                                        |
+   | PHP Version 7                                                        |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2011 The PHP Group                                |
+   | Copyright (c) 1997-2018 The PHP Group                                |
    +----------------------------------------------------------------------+
    | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
@@ -17,16 +17,18 @@
    +----------------------------------------------------------------------+
 */
 
-/* $Id: php_math.h 306939 2011-01-01 02:19:59Z felipe $ */
+/* $Id$ */
 
 #ifndef PHP_MATH_H
 #define PHP_MATH_H
 
-PHPAPI char *_php_math_number_format(double, int, char , char);
-PHPAPI char * _php_math_longtobase(zval *arg, int base);
-PHPAPI long _php_math_basetolong(zval *arg, int base);
+PHPAPI double _php_math_round(double, int, int);
+PHPAPI zend_string *_php_math_number_format(double, int, char, char);
+PHPAPI zend_string *_php_math_number_format_ex(double, int, char *, size_t, char *, size_t);
+PHPAPI zend_string * _php_math_longtobase(zval *arg, int base);
+PHPAPI zend_long _php_math_basetolong(zval *arg, int base);
 PHPAPI int _php_math_basetozval(zval *arg, int base, zval *ret);
-PHPAPI char * _php_math_zvaltobase(zval *arg, int base TSRMLS_DC);
+PHPAPI zend_string * _php_math_zvaltobase(zval *arg, int base);
 
 PHP_FUNCTION(sin);
 PHP_FUNCTION(cos);
@@ -44,9 +46,7 @@ PHP_FUNCTION(is_infinite);
 PHP_FUNCTION(is_nan);
 PHP_FUNCTION(pow);
 PHP_FUNCTION(sqrt);
-PHP_FUNCTION(srand);
 PHP_FUNCTION(rand);
-PHP_FUNCTION(getrandmax);
 PHP_FUNCTION(mt_srand);
 PHP_FUNCTION(mt_rand);
 PHP_FUNCTION(mt_getrandmax);
@@ -65,9 +65,10 @@ PHP_FUNCTION(number_format);
 PHP_FUNCTION(fmod);
 PHP_FUNCTION(deg2rad);
 PHP_FUNCTION(rad2deg);
+PHP_FUNCTION(intdiv);
 
    /*
-   WARNING: these functions are expermental: they could change their names or 
+   WARNING: these functions are expermental: they could change their names or
    disappear in the next version of PHP!
    */
 PHP_FUNCTION(hypot);
